/******************************************************************************/
/*                                                                            */
/*          SAS Program for TIMSS Advanced 2008 User Guide Example 3          */
/*            TIMSS Advanced 2008 International Report Exhibit 5.1            */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME TA08 "<datpath>" ;

* Issue the include command to include the JACKGPV macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKPV.SAS" ;

* Get and sort the teacher data ;

PROC SORT DATA = TA08.MTGALLM2 OUT = MTGALLM2 ;
     BY IDCNTRY IDTEACH IDLINK ;

* Get and sort the student-teacher linkage data ;

PROC SORT DATA = TA08.MSTALLM2 OUT = MSTALLM2 ;
     BY IDCNTRY IDTEACH IDLINK ;

* Merge the two files ;

DATA MERGED ;
     MERGE MTGALLM2 (IN = INMTG)
           MSTALLM2 (IN = INMST) ;
     BY IDCNTRY IDTEACH IDLINK ;
     IF INMTG AND INMST ;

* Read the merged file and select cases of interest ;

DATA MERGED ;
     SET MERGED ;

     * Select cases with no missing data ;

     IF NMISS (MT2GAGE) = 0 ;

     * Combine categories of BT4GAGE ;

     SELECT (MT2GAGE) ;
      WHEN (1,2) NEWAGE = 1 ;  * 29 YEARS OR UNDER ;
      WHEN (3)   NEWAGE = 2 ;  * 30 TO 39 YEARS    ;
      WHEN (4)   NEWAGE = 3 ;  * 40 TO 49 YEARS    ;
      WHEN (5,6) NEWAGE = 4 ;  * 50 YEARS OR OLDER ;
      OTHERWISE  NEWAGE = . ;
     END ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   051 = 'ARMENIA'
   364 = 'IRAN, ISLAMIC REP. OF'
   380 = 'ITALY'
   422 = 'LEBANON'
   528 = 'NETHERLANDS'
   578 = 'NORWAY'
   608 = 'PHILIPPINES'
   643 = 'RUSSIAN FEDERATION'
   705 = 'SLOVENIA'
   752 = 'SWEDEN' ;

 VALUE AGE
     1 = '29 YEARS OR UNDER'
     2 = '30 TO 39 YEARS   '
     3 = '40 TO 49 YEARS   '
     4 = '50 YEARS OR OLDER' ;

* Invoke the JACKPV macro to compute the statistics ;

%JACKPV (MATWGT, JKZONE, JKREP, 75, IDCNTRY NEWAGE, MSMMAT0, 5, MERGED) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY NEWAGE N MATWGT MNPV MNPV_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. NEWAGE AGE. N 6.0 MATWGT 10.0
            MNPV MNPV_SE PCT PCT_SE 6.2 ;
RUN ;
