/******************************************************************************/
/*                                                                            */
/*       SAS Program to Join SAS Data Files into a Single SAS Data File       */
/*                       TIMSS Advanced 2008 User Guide                       */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES ;

* Specify the file type ;
* <type> must be edited ;
* MCG/PCG - MSA/PSA - MSC/PSC - MSG/PSG - MSR/PSR - MST/PST - MTG/PTG ;

%LET TYPE = <type> ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <path> must be edited ;

LIBNAME LIBDAT "<path>" ;

%MACRO DOIT ;

   * Specify the list of countries to be processed ;

   %IF %UPCASE(%SUBSTR(&TYPE,1,1)) = M %THEN %DO; * 4th grade countries ;

      %LET COUNTRY = ARM IRN ITA LBN NLD NOR PHL RUS SVN SWE ;

   %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,1,1)) = P %THEN %DO ; * 8th grade countries ;

      %LET COUNTRY = ARM IRN ITA LBN NLD NOR RUS SVN SWE ;

   %END;

   DATA &TYPE.ALLM2 ;
        SET %LET I = 1 ;
            %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
               %LET CTRY = %SCAN(&COUNTRY,&I) ;
                  LIBDAT.&TYPE&CTRY.M2
               %LET I = %EVAL(&I + 1) ;
            %END ; ;
   RUN ;

   * Specify the sorting variables ;
   * Dependent of the file type ;

   %LET SORTVARS = IDCNTRY IDSTUD ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = C %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSCHOOL ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDTEACH IDLINK ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,3,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSTUD IDTEACH IDLINK ; %END ;

   PROC SORT DATA=&TYPE.ALLM2 OUT=LIBDAT.&TYPE.ALLM2 ;
        BY &SORTVARS ;
   RUN ;

%MEND DOIT ;

%DOIT ;
