/******************************************************************************/
/*                                                                            */
/*                SAS Program to Score the TIMSS Advanced 2008                */
/*                         Advanced Mathematics Items                         */
/*                       TIMSS Advanced 2008 User Guide                       */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <path> must be edited ;

LIBNAME LIBDAT "<path>" ;

* Specify the list of countries to be processed ;

%LET COUNTRY = ARM IRN ITA LBN NLD NOR PHL RUS SVN SWE ;

* List of multiple-choice items with A key ;

%LET ARIGHT = MA13002  MA13007  MA13011  MA13021  MA23185  MA23064  MA23082
              MA23208  MA23080  MA23041  ;

* List of multiple-choice items with B key ;

%LET BRIGHT = MA13004  MA13018  MA13019  MA13024  MA23005  MA23176  MA23042
              MA23021  MA23004  MA23063  MA23050  ;

* List of multiple-choice items with C key ;

%LET CRIGHT = MA13009  MA13012  MA13015  MA13020  MA23076  MA23098  MA23144
              MA23045  MA23151  ;

* List of multiple-choice items with D key ;

%LET DRIGHT = MA13001  MA13006  MA13008  MA13016  MA23206  MA23020  MA23069
              MA23039  MA23055  MA23133  MA23158  MA23182  ;

* List of multiple-choice items with E key ;

%LET ERIGHT = MA13003  MA13013  MA13017  ;

* List of constructed-response items ;

%LET CONSTR = MA13025A MA13025B MA13026A MA13026B MA13027  MA13028  MA13029
              MA23145  MA23187  MA23201  MA23154  MA23166  MA23043  MA23054
              MA23131A MA23131B MA23157  MA23094  MA23135  MA23165  MA23159
              MA23198  MA23141  MA23035A MA23035B MA23170  ;

%MACRO SCOREIT (ITEM, TYPE, RIGHT, NR, NA, OM, OTHER) ;

   * Code for multiple-choice items ;

   %IF %UPCASE(&TYPE) = "MC" %THEN %DO ;
      SCORE = 0 ;
         IF &ITEM = &RIGHT THEN SCORE = 1 ;
         IF &ITEM = &NR    THEN SCORE = 0 ; * Not Reached ;
         IF &ITEM = &NA    THEN SCORE = . ; * Not Administered ;
         IF &ITEM = &OM    THEN SCORE = 0 ; * Omitted ;
         IF &ITEM = &OTHER THEN SCORE = 0 ; * Other Missing ;
      &ITEM = SCORE ;
   %END ;

   * Code for constructed-response items ;

   %IF %UPCASE(&TYPE) = "CR" %THEN %DO ;
      SCORE = 0 ;
         IF &ITEM >= 20 AND &ITEM < 30 THEN SCORE = 2 ;
         IF &ITEM >= 10 AND &ITEM < 20 THEN SCORE = 1 ;
         IF &ITEM >= 70 AND &ITEM < 80 THEN SCORE = 0 ;
         IF &ITEM = &NR    THEN SCORE = 0 ; * Not Reached ;
         IF &ITEM = &NA    THEN SCORE = . ; * Not Administered ;
         IF &ITEM = &OM    THEN SCORE = 0 ; * Omitted ;
         IF &ITEM = &OTHER THEN SCORE = 0 ; * Other Missing ;
      &ITEM = SCORE ;
   %END ;

%MEND SCOREIT ;

%MACRO DOIT ;

   * Start of country processing loop ;

   %LET I = 1 ;
   %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
      %LET CTRY = %SCAN(&COUNTRY,&I) ;

      * Get the student achievement data ;

      DATA LIBDAT.MSC&CTRY.M2; * Output File ;
           SET LIBDAT.MSA&CTRY.M2; * Input File  ;

           ARRAY ARIGHT &ARIGHT ;
           ARRAY BRIGHT &BRIGHT ;
           ARRAY CRIGHT &CRIGHT ;
           ARRAY DRIGHT &DRIGHT ;
           ARRAY ERIGHT &ERIGHT ;
           ARRAY CONSTR &CONSTR ;

           DO OVER ARIGHT ; %SCOREIT (ARIGHT, "MC", 1, .R, .A, ., .I) ; END ;
           DO OVER BRIGHT ; %SCOREIT (BRIGHT, "MC", 2, .R, .A, ., .I) ; END ;
           DO OVER CRIGHT ; %SCOREIT (CRIGHT, "MC", 3, .R, .A, ., .I) ; END ;
           DO OVER DRIGHT ; %SCOREIT (DRIGHT, "MC", 4, .R, .A, ., .I) ; END ;
           DO OVER ERIGHT ; %SCOREIT (ERIGHT, "MC", 5, .R, .A, ., .I) ; END ;
           DO OVER CONSTR ; %SCOREIT (CONSTR, "CR",  , .R, .A, ., .I) ; END ;

      RUN ;

      * End of country processing loop ;

      %LET I = %EVAL(&I + 1) ;
   %END ;

%MEND DOIT ;

%DOIT ;
